@@ -1,16 +1,17 @@
 import os
 
-import pytest
-import xyzservices.providers as xyz
-import requests
 import mercantile
+import pytest
+import requests
+
+import xyzservices.providers as xyz
 
 flat_free = xyz.filter(requires_token=False).flatten()
 
 
 def check_provider(provider):
     for key in ["attribution", "name"]:
-        assert key in provider.keys()
+        assert key in provider
     assert provider.url.startswith("http")
     for option in ["{z}", "{y}", "{x}"]:
         assert option in provider.url
@@ -85,7 +86,7 @@ def get_test_result(provider, allow_403=True):
                 z, x, y = o
                 r = get_response(provider.build_url(z=z, x=x, y=y))
                 results.append(r)
-            if not any([x == requests.codes.ok for x in results]):
+            if not any(x == requests.codes.ok for x in results):
                 raise ValueError(f"Response code: {r}")
         else:
             raise ValueError(f"Response code: {r}")
@@ -101,6 +102,8 @@ def test_minimal_provider_metadata(provider_name):
 @pytest.mark.parametrize("name", flat_free)
 def test_free_providers(name):
     provider = flat_free[name]
+    if "Stadia" in name:
+        pytest.skip("Stadia doesn't support tile download in this way.")
     get_test_result(provider)
 
 
@@ -192,18 +195,19 @@ def test_openweathermap(provider_name):
     get_test_result(provider, allow_403=False)
 
 
-@pytest.mark.request
-@pytest.mark.parametrize("provider_name", xyz.HEREv3)
-def test_herev3(provider_name):
-    try:
-        token = os.environ["HEREV3"]
-    except KeyError:
-        pytest.xfail("Missing API token.")
-    if token == "":
-        pytest.xfail("Token empty.")
+# HEREV3 seems to block GHA as it errors with E429
+# @pytest.mark.request
+# @pytest.mark.parametrize("provider_name", xyz.HEREv3)
+# def test_herev3(provider_name):
+#     try:
+#         token = os.environ["HEREV3"]
+#     except KeyError:
+#         pytest.xfail("Missing API token.")
+#     if token == "":
+#         pytest.xfail("Token empty.")
 
-    provider = xyz.HEREv3[provider_name](apiKey=token)
-    get_test_result(provider, allow_403=False)
+#     provider = xyz.HEREv3[provider_name](apiKey=token)
+#     get_test_result(provider, allow_403=False)
 
 
 @pytest.mark.request
@@ -221,5 +225,19 @@ def test_stadia(provider_name):
     get_test_result(provider, allow_403=False)
 
 
+@pytest.mark.request
+@pytest.mark.parametrize("provider_name", xyz.OrdnanceSurvey)
+def test_os(provider_name):
+    try:
+        token = os.environ["ORDNANCESURVEY"]
+    except KeyError:
+        pytest.xfail("Missing API token.")
+    if token == "":
+        pytest.xfail("Token empty.")
+
+    provider = xyz.OrdnanceSurvey[provider_name](key=token)
+    get_test_result(provider, allow_403=False)
+
+
 # NOTE: AzureMaps are not tested as their free account is limited to
 # 5000 downloads (total, not per month)
